import type { APIRoute } from "astro"
import { supabase } from "@library/supabase"

export const POST: APIRoute = async ({ request, redirect }) => {
  const formData = await request.formData()
  const avatar_url = formData.get("avatar_url")?.toString()

  if (!avatar_url) {
    return new Response("Error.", { status: 400 })
  }

  // https://supabase.com/docs/reference/javascript/auth-updateuser?example=update-the-users-metadata
  const { error } = await supabase.auth.updateUser({
    data: {
      avatar_url: avatar_url
    }
  })

  if (error) {
    return new Response(error.message, { status: 500 })
  }

  return redirect("/account?=AvatarUpdated")
}
