import type { APIRoute } from "astro"
import { supabase } from "@library/supabase"

export const POST: APIRoute = async ({ request, redirect }) => {
  const formData = await request.formData()
  const avatar_url = formData.get("avatar_url")?.toString()
  const name = formData.get("name")?.toString()
  const email = formData.get("email")?.toString()
  const password = formData.get("password")?.toString()

  if (!email || !password || !name || !avatar_url) {
    return new Response("Email and password are required", { status: 400 })
  }

  // https://supabase.com/docs/reference/javascript/auth-signup?example=sign-up-with-additional-user-metadata
  const { error } = await supabase.auth.signUp({
    options: {
      emailRedirectTo: "http://localhost:4321/?=welcome",
      data: {
        full_name: name,
        avatar_url: avatar_url,
        plan: "Free",
        theme: "Dark",
        color_scheme: "Green",
        beta: true,
      }
    },
    email,
    password,
  })

  if (error) {
    return new Response(error.message, { status: 500 })
  }

  return redirect("/account/email-confirm")
}
